@@ -1,10 +1,15 @@
 #include "mainwindow.hpp"
+
+#include "metatypes.hpp"
+#include "dialog/whatsnew.hpp"
 #include "lib/time.hpp"
-#include "lib/system.hpp"
-#include "util/widget.hpp"
-#include "util/font.hpp"
+#include "lib/crash/crashhandler.hpp"
 #include "menu/mainmenubar.hpp"
 #include "util/appconfig.hpp"
+#include "util/url.hpp"
+#include "util/widget.hpp"
+#include "view/sidepanel/view.hpp"
+#include "widget/hiddensizegrip.hpp"
 
 #ifdef _WIN32
 #include "windows.h"
@@ -413,12 +418,16 @@ void MainWindow::addSizeGrip(const std::function<QPoint(const QRect &)> &positio
 
 void MainWindow::minimize()
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
 	// HACK: Qt windows that are restored are sometimes still marked minimized
 	// so we have to remove that flag if present before trying to minimize.
 	//
 	// See https://github.com/kraxarn/spotify-qt/issues/103
 	setWindowState(windowState() & ~Qt::WindowMinimized);
 	setWindowState(windowState() | Qt::WindowMinimized);
+#else
+	setWindowState(Qt::WindowMinimized);
+#endif
 }
 
 void MainWindow::refresh()
